@@ -21,9 +21,9 @@ BEGIN {
     ) unless overload::Method( Types::Bool, '0+' );
 
     require constant;
-    constant->import( true => bless \( my $dummy = 1 ), 'Types::Bool' )
+    constant->import( true => do { bless \( my $dummy = 1 ), 'Types::Bool' } )
       unless Types::Bool->can('true');
-    constant->import( false => bless \( my $dummy = 0 ), 'Types::Bool' )
+    constant->import( false => do { bless \( my $dummy = 0 ), 'Types::Bool' } )
       unless Types::Bool->can('false');
 
     unless ( Types::Bool->can('is_bool') ) {
@@ -31,7 +31,7 @@ BEGIN {
         *is_bool = sub ($) { Scalar::Util::blessed( $_[0] ) and $_[0]->isa('Types::Bool') };
     }
 
-    $Types::Bool::VERSION = '2.98004'
+    $Types::Bool::VERSION = '2.98005'
       unless $Types::Bool::VERSION;
 }
 
